<?php

/**
 * The core plugin class.
 *
 * @since      1.0.0
 * @package    WpSecure
 * @subpackage WpSecure/includes
 * @author     WpSecure <contact@WpSecure.com>
 */
class WpSecure{

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 */
	public function __construct() {
		global $wpdb,$wpsecure;
		$this->wpsecure = get_option('wps_options',false);
		if ( defined( 'WPS_VERSION' ) ) {
			$this->version = WPS_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'wps';
	
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		
		$this->wpsecure_loginUrl_hooks();
		$this->wpsecure_hidePaths_hooks();
		$this->wpsecure_brute_hooks();
		$this->wpsecure_2fauth_hooks();
		
		//$this->wpsecure_hideWp_hooks();
		//$this->wpsecure_brute_hooks();
		
		//$this->define_public_hooks();
		//$this->define_wp_hide_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Plugin_Name_Loader. Orchestrates the hooks of the plugin.
	 * - Plugin_Name_i18n. Defines internationalization functionality.
	 * - Plugin_Name_Admin. Defines all hooks for the admin area.
	 * - Plugin_Name_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 */
	private function load_dependencies() {

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wpsecure-loader.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wpsecure-i18n.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-wpsecure-admin.php';
		//require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-wpsecure-admin.php';
		
		//require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-wpsecure-public.php';
		//require_once plugin_dir_path( dirname( __FILE__ ) ) . 'wphide/class-wpsecurehide.php';
		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'classes/login/class-wpsecure-loginurl.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'classes/hide/class-wpsecure-hidepaths.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'classes/brute/class-wpsecure-brute.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'classes/2fauth/class-wpsecure-2fauth.php';

		$this->loader = new WpSecure_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Plugin_Name_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 */
	private function set_locale() {

		$plugin_i18n = new WpSecure_i18n();
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 */
	private function define_admin_hooks() {

		$plugin_admin = new WpSecure_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		// Add menu item
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'wpsecure_admin_menu' );

	}

	public function define_public_hooks() {

		$plugin_public = new WpSecure_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}
	
	public function define_wp_hide_hooks() {
		//$plugin_hide = new WpSecureHide( $this->get_plugin_name(), $this->get_version() );
	}	
	
	public function wpsecure_loginUrl_hooks(){
		$wps_login_url = new WpSecureLoginUrl( $this->wpsecure );
	}
	
	public function wpsecure_hidePaths_hooks(){
		$wps_hide = new WpSecureHidePaths( $this->wpsecure );
	}
	
	public function wpsecure_brute_hooks(){
		$wps_brute = new WpSecureBrute( $this->wpsecure );
	}
	
	public function wpsecure_2fauth_hooks(){
		$wps_2fauth = new WpSecure2fauth( $this->wpsecure );
	}
	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
